/*****************************************************************************
 * Copyright (C) 2004
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 *****************************************************************************/
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

namespace iOpener
{
	/// <summary>
	/// This class is the preferences dialog for iOpener.
	/// </summary>
	public class PrefsDialog : System.Windows.Forms.Form
	{
		private ToolTip			toolTip1;
		private Button			okButton;
		private Button			cancelButton;
		private CheckBox		copyFilesCheckbox;
		private CheckBox		autoDecryptCheckbox;
		private IContainer		components;

		/// <summary>
		/// This constructor method does the standard component init plus it sets
		/// the state of the checkboxes to whatever was passed in as params.
		/// </summary>
		/// <param name="shouldCopyFiles"></param>
		/// <param name="shouldAutoDecrypt"></param>
		public PrefsDialog(bool shouldCopyFiles, bool shouldAutoDecrypt)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();
			this.copyFilesCheckbox.Checked = shouldCopyFiles;
			this.autoDecryptCheckbox.Checked = shouldAutoDecrypt;
		}

		/// <summary>
		/// This method is the public accessor for the shouldCopyFiles pref
		/// </summary>
		/// <returns></returns>
		public bool ShouldCopyFiles() 
		{
			return this.copyFilesCheckbox.Checked;
		}

		/// <summary>
		/// This method is the public accessor for the shouldAutoDecrypt pref
		/// </summary>
		/// <returns></returns>
		public bool ShouldAutoDecrypt()
		{
			return this.autoDecryptCheckbox.Checked;
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.components = new System.ComponentModel.Container();
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(PrefsDialog));
			this.copyFilesCheckbox = new System.Windows.Forms.CheckBox();
			this.autoDecryptCheckbox = new System.Windows.Forms.CheckBox();
			this.toolTip1 = new System.Windows.Forms.ToolTip(this.components);
			this.okButton = new System.Windows.Forms.Button();
			this.cancelButton = new System.Windows.Forms.Button();
			this.SuspendLayout();
			// 
			// copyFilesCheckbox
			// 
			this.copyFilesCheckbox.Checked = true;
			this.copyFilesCheckbox.CheckState = System.Windows.Forms.CheckState.Checked;
			this.copyFilesCheckbox.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.copyFilesCheckbox.Location = new System.Drawing.Point(16, 8);
			this.copyFilesCheckbox.Name = "copyFilesCheckbox";
			this.copyFilesCheckbox.Size = new System.Drawing.Size(208, 24);
			this.copyFilesCheckbox.TabIndex = 0;
			this.copyFilesCheckbox.Text = "Copy original tracks before iOpening";
			this.toolTip1.SetToolTip(this.copyFilesCheckbox, "Check this box to have iOpener make a backup copy of your track before iOpening");
			// 
			// autoDecryptCheckbox
			// 
			this.autoDecryptCheckbox.Checked = true;
			this.autoDecryptCheckbox.CheckState = System.Windows.Forms.CheckState.Checked;
			this.autoDecryptCheckbox.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.autoDecryptCheckbox.Location = new System.Drawing.Point(16, 40);
			this.autoDecryptCheckbox.Name = "autoDecryptCheckbox";
			this.autoDecryptCheckbox.Size = new System.Drawing.Size(256, 24);
			this.autoDecryptCheckbox.TabIndex = 1;
			this.autoDecryptCheckbox.Text = "Automatically iOpen newly added tracks";
			this.toolTip1.SetToolTip(this.autoDecryptCheckbox, "Check this box for iOpener to decrypt files when they are added to your library. " +
				" This will keep iOpener running in your task tray.");
			// 
			// okButton
			// 
			this.okButton.DialogResult = System.Windows.Forms.DialogResult.OK;
			this.okButton.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.okButton.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.okButton.Location = new System.Drawing.Point(55, 80);
			this.okButton.Name = "okButton";
			this.okButton.TabIndex = 2;
			this.okButton.Text = "&OK";
			// 
			// cancelButton
			// 
			this.cancelButton.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.cancelButton.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.cancelButton.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.cancelButton.Location = new System.Drawing.Point(143, 80);
			this.cancelButton.Name = "cancelButton";
			this.cancelButton.TabIndex = 3;
			this.cancelButton.Text = "&Cancel";
			// 
			// PrefsDialog
			// 
			this.AcceptButton = this.okButton;
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.CancelButton = this.cancelButton;
			this.ClientSize = new System.Drawing.Size(272, 118);
			this.Controls.Add(this.cancelButton);
			this.Controls.Add(this.okButton);
			this.Controls.Add(this.autoDecryptCheckbox);
			this.Controls.Add(this.copyFilesCheckbox);
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.Name = "PrefsDialog";
			this.Text = "iOpener Preferences";
			this.ResumeLayout(false);

		}
		#endregion
	}
}
